CrashEvent class
Represents a discrete anomaly or physical crash detected by the hardware sensors and AI model.
Constructors
- CrashEvent({required double probability, required DateTime timestamp})
-
Creates a CrashEvent with the given
probabilityandtimestamp.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- probability → double
-
The AI's confidence that the event is an actual crash. Ranges from 0.0 to 1.0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
The exact timestamp when the anomaly was detected.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited